==> google_shopping_merchant_lfp-0.1.0-py3-none-any.whl: google/shopping/merchant_lfp_v1beta/services/lfp_inventory_service/async_client.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import (
    Dict,
    Mapping,
    MutableMapping,
    MutableSequence,
    Optional,
    Sequence,
    Tuple,
    Type,
    Union,
)

from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry_async as retries
from google.api_core.client_options import ClientOptions
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.shopping.merchant_lfp_v1beta import gapic_version as package_version

try:
    OptionalRetry = Union[retries.AsyncRetry, gapic_v1.method._MethodDefault, None]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.AsyncRetry, object, None]  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore
from google.shopping.type.types import types

from google.shopping.merchant_lfp_v1beta.types import lfpinventory

from .client import LfpInventoryServiceClient
from .transports.base import DEFAULT_CLIENT_INFO, LfpInventoryServiceTransport
from .transports.grpc_asyncio import LfpInventoryServiceGrpcAsyncIOTransport


class LfpInventoryServiceAsyncClient:
    """Service for a `LFP
    partner <https://support.google.com/merchants/answer/7676652>`__ to
    submit local inventories for a merchant.
    """

    _client: LfpInventoryServiceClient

    # Copy defaults from the synchronous client for use here.
    # Note: DEFAULT_ENDPOINT is deprecated. Use _DEFAULT_ENDPOINT_TEMPLATE instead.
    DEFAULT_ENDPOINT = LfpInventoryServiceClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = LfpInventoryServiceClient.DEFAULT_MTLS_ENDPOINT
    _DEFAULT_ENDPOINT_TEMPLATE = LfpInventoryServiceClient._DEFAULT_ENDPOINT_TEMPLATE
    _DEFAULT_UNIVERSE = LfpInventoryServiceClient._DEFAULT_UNIVERSE

    lfp_inventory_path = staticmethod(LfpInventoryServiceClient.lfp_inventory_path)
    parse_lfp_inventory_path = staticmethod(
        LfpInventoryServiceClient.parse_lfp_inventory_path
    )
    common_billing_account_path = staticmethod(
        LfpInventoryServiceClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        LfpInventoryServiceClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(LfpInventoryServiceClient.common_folder_path)
    parse_common_folder_path = staticmethod(
        LfpInventoryServiceClient.parse_common_folder_path
    )
    common_organization_path = staticmethod(
        LfpInventoryServiceClient.common_organization_path
    )
    parse_common_organization_path = staticmethod(
        LfpInventoryServiceClient.parse_common_organization_path
    )
    common_project_path = staticmethod(LfpInventoryServiceClient.common_project_path)
    parse_common_project_path = staticmethod(
        LfpInventoryServiceClient.parse_common_project_path
    )
    common_location_path = staticmethod(LfpInventoryServiceClient.common_location_path)
    parse_common_location_path = staticmethod(
        LfpInventoryServiceClient.parse_common_location_path
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            LfpInventoryServiceAsyncClient: The constructed client.
        """
        return LfpInventoryServiceClient.from_service_account_info.__func__(LfpInventoryServiceAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            LfpInventoryServiceAsyncClient: The constructed client.
        """
        return LfpInventoryServiceClient.from_service_account_file.__func__(LfpInventoryServiceAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: Optional[ClientOptions] = None
    ):
        """Return the API endpoint and client cert source for mutual TLS.

        The client cert source is determined in the following order:
        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
        client cert source is None.
        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
        default client cert source exists, use the default one; otherwise the client cert
        source is None.

        The API endpoint is determined in the following order:
        (1) if `client_options.api_endpoint` if provided, use the provided one.
        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
        default mTLS endpoint; if the environment variable is "never", use the default API
        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
        use the default API endpoint.

        More details can be found at https://google.aip.dev/auth/4114.

        Args:
            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                client. Only the `api_endpoint` and `client_cert_source` properties may be used
                in this method.

        Returns:
            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
                client cert source to use.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
        """
        return LfpInventoryServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore

    @property
    def transport(self) -> LfpInventoryServiceTransport:
        """Returns the transport used by the client instance.

        Returns:
            LfpInventoryServiceTransport: The transport used by the client instance.
        """
        return self._client.transport

    @property
    def api_endpoint(self):
        """Return the API endpoint used by the client instance.

        Returns:
            str: The API endpoint used by the client instance.
        """
        return self._client._api_endpoint

    @property
    def universe_domain(self) -> str:
        """Return the universe domain used by the client instance.

        Returns:
            str: The universe domain used
                by the client instance.
        """
        return self._client._universe_domain

    get_transport_class = functools.partial(
        type(LfpInventoryServiceClient).get_transport_class,
        type(LfpInventoryServiceClient),
    )

    def __init__(
        self,
        *,
        credentials: Optional[ga_credentials.Credentials] = None,
        transport: Union[str, LfpInventoryServiceTransport] = "grpc_asyncio",
        client_options: Optional[ClientOptions] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the lfp inventory service async client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, ~.LfpInventoryServiceTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]):
                Custom options for the client.

                1. The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client when ``transport`` is
                not explicitly provided. Only if this property is not set and
                ``transport`` was not explicitly provided, the endpoint is
                determined by the GOOGLE_API_USE_MTLS_ENDPOINT environment
                variable, which have one of the following values:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto-switch to the
                default mTLS endpoint if client certificate is present; this is
                the default value).

                2. If the GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide a client certificate for mTLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

                3. The ``universe_domain`` property can be used to override the
                default "googleapis.com" universe. Note that ``api_endpoint``
                property still takes precedence; and ``universe_domain`` is
                currently not supported for mTLS.

            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = LfpInventoryServiceClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

    async def insert_lfp_inventory(
        self,
        request: Optional[Union[lfpinventory.InsertLfpInventoryRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> lfpinventory.LfpInventory:
        r"""Inserts a ``LfpInventory`` resource for the given target
        merchant account. If the resource already exists, it will be
        replaced. The inventory automatically expires after 30 days.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.shopping import merchant_lfp_v1beta

            async def sample_insert_lfp_inventory():
                # Create a client
                client = merchant_lfp_v1beta.LfpInventoryServiceAsyncClient()

                # Initialize request argument(s)
                lfp_inventory = merchant_lfp_v1beta.LfpInventory()
                lfp_inventory.target_account = 1491
                lfp_inventory.store_code = "store_code_value"
                lfp_inventory.offer_id = "offer_id_value"
                lfp_inventory.region_code = "region_code_value"
                lfp_inventory.content_language = "content_language_value"
                lfp_inventory.availability = "availability_value"

                request = merchant_lfp_v1beta.InsertLfpInventoryRequest(
                    parent="parent_value",
                    lfp_inventory=lfp_inventory,
                )

                # Make the request
                response = await client.insert_lfp_inventory(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.shopping.merchant_lfp_v1beta.types.InsertLfpInventoryRequest, dict]]):
                The request object. Request message for the ``InsertLfpInventory`` method.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.shopping.merchant_lfp_v1beta.types.LfpInventory:
                Local Inventory for the merchant.
        """
        # Create or coerce a protobuf request object.
        request = lfpinventory.InsertLfpInventoryRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.insert_lfp_inventory,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def __aenter__(self) -> "LfpInventoryServiceAsyncClient":
        return self

    async def __aexit__(self, exc_type, exc, tb):
        await self.transport.close()


DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


__all__ = ("LfpInventoryServiceAsyncClient",)

==> google_shopping_merchant_lfp-0.1.1-py3-none-any.whl: google/shopping/merchant_lfp_v1beta/services/lfp_inventory_service/async_client.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import (
    Callable,
    Dict,
    Mapping,
    MutableMapping,
    MutableSequence,
    Optional,
    Sequence,
    Tuple,
    Type,
    Union,
)

from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry_async as retries
from google.api_core.client_options import ClientOptions
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.shopping.merchant_lfp_v1beta import gapic_version as package_version

try:
    OptionalRetry = Union[retries.AsyncRetry, gapic_v1.method._MethodDefault, None]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.AsyncRetry, object, None]  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore
from google.shopping.type.types import types

from google.shopping.merchant_lfp_v1beta.types import lfpinventory

from .client import LfpInventoryServiceClient
from .transports.base import DEFAULT_CLIENT_INFO, LfpInventoryServiceTransport
from .transports.grpc_asyncio import LfpInventoryServiceGrpcAsyncIOTransport


class LfpInventoryServiceAsyncClient:
    """Service for a `LFP
    partner <https://support.google.com/merchants/answer/7676652>`__ to
    submit local inventories for a merchant.
    """

    _client: LfpInventoryServiceClient

    # Copy defaults from the synchronous client for use here.
    # Note: DEFAULT_ENDPOINT is deprecated. Use _DEFAULT_ENDPOINT_TEMPLATE instead.
    DEFAULT_ENDPOINT = LfpInventoryServiceClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = LfpInventoryServiceClient.DEFAULT_MTLS_ENDPOINT
    _DEFAULT_ENDPOINT_TEMPLATE = LfpInventoryServiceClient._DEFAULT_ENDPOINT_TEMPLATE
    _DEFAULT_UNIVERSE = LfpInventoryServiceClient._DEFAULT_UNIVERSE

    lfp_inventory_path = staticmethod(LfpInventoryServiceClient.lfp_inventory_path)
    parse_lfp_inventory_path = staticmethod(
        LfpInventoryServiceClient.parse_lfp_inventory_path
    )
    common_billing_account_path = staticmethod(
        LfpInventoryServiceClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        LfpInventoryServiceClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(LfpInventoryServiceClient.common_folder_path)
    parse_common_folder_path = staticmethod(
        LfpInventoryServiceClient.parse_common_folder_path
    )
    common_organization_path = staticmethod(
        LfpInventoryServiceClient.common_organization_path
    )
    parse_common_organization_path = staticmethod(
        LfpInventoryServiceClient.parse_common_organization_path
    )
    common_project_path = staticmethod(LfpInventoryServiceClient.common_project_path)
    parse_common_project_path = staticmethod(
        LfpInventoryServiceClient.parse_common_project_path
    )
    common_location_path = staticmethod(LfpInventoryServiceClient.common_location_path)
    parse_common_location_path = staticmethod(
        LfpInventoryServiceClient.parse_common_location_path
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            LfpInventoryServiceAsyncClient: The constructed client.
        """
        return LfpInventoryServiceClient.from_service_account_info.__func__(LfpInventoryServiceAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            LfpInventoryServiceAsyncClient: The constructed client.
        """
        return LfpInventoryServiceClient.from_service_account_file.__func__(LfpInventoryServiceAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: Optional[ClientOptions] = None
    ):
        """Return the API endpoint and client cert source for mutual TLS.

        The client cert source is determined in the following order:
        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
        client cert source is None.
        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
        default client cert source exists, use the default one; otherwise the client cert
        source is None.

        The API endpoint is determined in the following order:
        (1) if `client_options.api_endpoint` if provided, use the provided one.
        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
        default mTLS endpoint; if the environment variable is "never", use the default API
        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
        use the default API endpoint.

        More details can be found at https://google.aip.dev/auth/4114.

        Args:
            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                client. Only the `api_endpoint` and `client_cert_source` properties may be used
                in this method.

        Returns:
            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
                client cert source to use.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
        """
        return LfpInventoryServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore

    @property
    def transport(self) -> LfpInventoryServiceTransport:
        """Returns the transport used by the client instance.

        Returns:
            LfpInventoryServiceTransport: The transport used by the client instance.
        """
        return self._client.transport

    @property
    def api_endpoint(self):
        """Return the API endpoint used by the client instance.

        Returns:
            str: The API endpoint used by the client instance.
        """
        return self._client._api_endpoint

    @property
    def universe_domain(self) -> str:
        """Return the universe domain used by the client instance.

        Returns:
            str: The universe domain used
                by the client instance.
        """
        return self._client._universe_domain

    get_transport_class = functools.partial(
        type(LfpInventoryServiceClient).get_transport_class,
        type(LfpInventoryServiceClient),
    )

    def __init__(
        self,
        *,
        credentials: Optional[ga_credentials.Credentials] = None,
        transport: Optional[
            Union[
                str,
                LfpInventoryServiceTransport,
                Callable[..., LfpInventoryServiceTransport],
            ]
        ] = "grpc_asyncio",
        client_options: Optional[ClientOptions] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the lfp inventory service async client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Optional[Union[str,LfpInventoryServiceTransport,Callable[..., LfpInventoryServiceTransport]]]):
                The transport to use, or a Callable that constructs and returns a new transport to use.
                If a Callable is given, it will be called with the same set of initialization
                arguments as used in the LfpInventoryServiceTransport constructor.
                If set to None, a transport is chosen automatically.
            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]):
                Custom options for the client.

                1. The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client when ``transport`` is
                not explicitly provided. Only if this property is not set and
                ``transport`` was not explicitly provided, the endpoint is
                determined by the GOOGLE_API_USE_MTLS_ENDPOINT environment
                variable, which have one of the following values:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto-switch to the
                default mTLS endpoint if client certificate is present; this is
                the default value).

                2. If the GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide a client certificate for mTLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

                3. The ``universe_domain`` property can be used to override the
                default "googleapis.com" universe. Note that ``api_endpoint``
                property still takes precedence; and ``universe_domain`` is
                currently not supported for mTLS.

            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = LfpInventoryServiceClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

    async def insert_lfp_inventory(
        self,
        request: Optional[Union[lfpinventory.InsertLfpInventoryRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> lfpinventory.LfpInventory:
        r"""Inserts a ``LfpInventory`` resource for the given target
        merchant account. If the resource already exists, it will be
        replaced. The inventory automatically expires after 30 days.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.shopping import merchant_lfp_v1beta

            async def sample_insert_lfp_inventory():
                # Create a client
                client = merchant_lfp_v1beta.LfpInventoryServiceAsyncClient()

                # Initialize request argument(s)
                lfp_inventory = merchant_lfp_v1beta.LfpInventory()
                lfp_inventory.target_account = 1491
                lfp_inventory.store_code = "store_code_value"
                lfp_inventory.offer_id = "offer_id_value"
                lfp_inventory.region_code = "region_code_value"
                lfp_inventory.content_language = "content_language_value"
                lfp_inventory.availability = "availability_value"

                request = merchant_lfp_v1beta.InsertLfpInventoryRequest(
                    parent="parent_value",
                    lfp_inventory=lfp_inventory,
                )

                # Make the request
                response = await client.insert_lfp_inventory(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.shopping.merchant_lfp_v1beta.types.InsertLfpInventoryRequest, dict]]):
                The request object. Request message for the ``InsertLfpInventory`` method.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.shopping.merchant_lfp_v1beta.types.LfpInventory:
                Local Inventory for the merchant.
        """
        # Create or coerce a protobuf request object.
        # - Use the request object if provided (there's no risk of modifying the input as
        #   there are no flattened fields), or create one.
        if not isinstance(request, lfpinventory.InsertLfpInventoryRequest):
            request = lfpinventory.InsertLfpInventoryRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._client._transport._wrapped_methods[
            self._client._transport.insert_lfp_inventory
        ]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def __aenter__(self) -> "LfpInventoryServiceAsyncClient":
        return self

    async def __aexit__(self, exc_type, exc, tb):
        await self.transport.close()


DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


__all__ = ("LfpInventoryServiceAsyncClient",)
